@@ -1,14 +1,17 @@
 import typing
 
-from cqrs import response
-from cqrs.requests import request, request_handler
+from cqrs.requests import request, request_handler, cor_request_handler
 
 _KT = typing.TypeVar("_KT", bound=typing.Type[request.Request])
 _VT = typing.TypeVar(
     "_VT",
     bound=typing.Type[
-        request_handler.RequestHandler[request.Request, response.Response]
-    ],
+        request_handler.RequestHandler | request_handler.SyncRequestHandler
+    ]
+    | typing.List[typing.Type[cor_request_handler.CORRequestHandler]]
+    | typing.List[typing.Type[cor_request_handler.SyncCORRequestHandler]]
+    | typing.Type[request_handler.StreamingRequestHandler]
+    | typing.Type[request_handler.SyncStreamingRequestHandler],
 )
 
 
